# -*- ruby encoding: utf-8 -*-
#############################################################
# This file was automatically generated on 2012-07-13.      #
#                                                           #
# If you have a bugfix for this file and want to commit it, #
# please fix the bug in the generator. You can find a link  #
# to the generator git on tinkerforge.com                   #
#############################################################

module Tinkerforge
  # Device for controlling Stacks and four Bricklets
  class BrickMaster < Device

    FUNCTION_GET_STACK_VOLTAGE = 1 # :nodoc:
    FUNCTION_GET_STACK_CURRENT = 2 # :nodoc:
    FUNCTION_SET_EXTENSION_TYPE = 3 # :nodoc:
    FUNCTION_GET_EXTENSION_TYPE = 4 # :nodoc:
    FUNCTION_IS_CHIBI_PRESENT = 5 # :nodoc:
    FUNCTION_SET_CHIBI_ADDRESS = 6 # :nodoc:
    FUNCTION_GET_CHIBI_ADDRESS = 7 # :nodoc:
    FUNCTION_SET_CHIBI_MASTER_ADDRESS = 8 # :nodoc:
    FUNCTION_GET_CHIBI_MASTER_ADDRESS = 9 # :nodoc:
    FUNCTION_SET_CHIBI_SLAVE_ADDRESS = 10 # :nodoc:
    FUNCTION_GET_CHIBI_SLAVE_ADDRESS = 11 # :nodoc:
    FUNCTION_GET_CHIBI_SIGNAL_STRENGTH = 12 # :nodoc:
    FUNCTION_GET_CHIBI_ERROR_LOG = 13 # :nodoc:
    FUNCTION_SET_CHIBI_FREQUENCY = 14 # :nodoc:
    FUNCTION_GET_CHIBI_FREQUENCY = 15 # :nodoc:
    FUNCTION_SET_CHIBI_CHANNEL = 16 # :nodoc:
    FUNCTION_GET_CHIBI_CHANNEL = 17 # :nodoc:
    FUNCTION_IS_RS485_PRESENT = 18 # :nodoc:
    FUNCTION_SET_RS485_ADDRESS = 19 # :nodoc:
    FUNCTION_GET_RS485_ADDRESS = 20 # :nodoc:
    FUNCTION_SET_RS485_SLAVE_ADDRESS = 21 # :nodoc:
    FUNCTION_GET_RS485_SLAVE_ADDRESS = 22 # :nodoc:
    FUNCTION_GET_RS485_ERROR_LOG = 23 # :nodoc:
    FUNCTION_SET_RS485_CONFIGURATION = 24 # :nodoc:
    FUNCTION_GET_RS485_CONFIGURATION = 25 # :nodoc:
    FUNCTION_RESET = 243 # :nodoc:
    FUNCTION_GET_CHIP_TEMPERATURE = 242 # :nodoc:

    # Creates an object with the unique device ID <tt>uid</tt>. This object can
    # then be added to the IP connection.
    def initialize(uid)
      super uid

      @expected_name = 'Master Brick'

      @binding_version = [1, 2, 1]

    end

    # Returns the stack voltage in mV. The stack voltage is the
    # voltage that is supplied via the stack, i.e. it is given by a 
    # Step-Down or Step-Up Power Supply.
    def get_stack_voltage
      send_request(FUNCTION_GET_STACK_VOLTAGE, [], '', 2, 'S')
    end

    # Returns the stack current in mA. The stack current is the
    # current that is drawn via the stack, i.e. it is given by a
    # Step-Down or Step-Up Power Supply.
    def get_stack_current
      send_request(FUNCTION_GET_STACK_CURRENT, [], '', 2, 'S')
    end

    # Writes the extension type to the EEPROM of a specified extension. 
    # The extension is either 0 or 1 (0 is the on the bottom, 1 is the on on top, 
    # if only one extension is present use 0).
    # 
    # Possible extension types:
    # 
    #  "Type", "Description"
    # 
    #  "1",    "Chibi"
    #  "2",    "RS485"
    # 
    # The extension type is already set when bought and it can be set with the 
    # Brick Viewer, it is unlikely that you need this function.
    # 
    # The value will be saved in the EEPROM of the Chibi Extension, it does not
    # have to be set on every startup.
    def set_extension_type(extension, exttype)
      send_request(FUNCTION_SET_EXTENSION_TYPE, [extension, exttype], 'C L', 0, '')
    end

    # Returns the extension type for a given extension as set by 
    # BrickMaster#set_extension_type.
    def get_extension_type(extension)
      send_request(FUNCTION_GET_EXTENSION_TYPE, [extension], 'C', 4, 'L')
    end

    # Returns true if a Chibi Extension is available to be used by the Master.
    # 
    # .. versionadded:: 1.1.0
    def is_chibi_present
      send_request(FUNCTION_IS_CHIBI_PRESENT, [], '', 1, '?')
    end

    # Sets the address (1-255) belonging to the Chibi Extension.
    # 
    # It is possible to set the address with the Brick Viewer and it will be 
    # saved in the EEPROM of the Chibi Extension, it does not
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.1.0
    def set_chibi_address(address)
      send_request(FUNCTION_SET_CHIBI_ADDRESS, [address], 'C', 0, '')
    end

    # Returns the address as set by BrickMaster#set_chibi_address.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_address
      send_request(FUNCTION_GET_CHIBI_ADDRESS, [], '', 1, 'C')
    end

    # Sets the address (1-255) of the Chibi Master. This address is used if the
    # Chibi Extension is used as slave (i.e. it does not have a USB connection).
    # 
    # It is possible to set the address with the Brick Viewer and it will be 
    # saved in the EEPROM of the Chibi Extension, it does not
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.1.0
    def set_chibi_master_address(address)
      send_request(FUNCTION_SET_CHIBI_MASTER_ADDRESS, [address], 'C', 0, '')
    end

    # Returns the address as set by BrickMaster#set_chibi_master_address.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_master_address
      send_request(FUNCTION_GET_CHIBI_MASTER_ADDRESS, [], '', 1, 'C')
    end

    # Sets up to 255 slave addresses. The address numeration has to be used
    # ascending from 0. For example: If you use the Chibi Extension in Master mode
    # (i.e. the stack has an USB connection) and you want to talk to three other
    # Chibi stacks with the IDs 17, 23, and 42, you should call with "(0, 17),
    # (1, 23) and (2, 42)".
    # 
    # It is possible to set the addresses with the Brick Viewer and it will be 
    # saved in the EEPROM of the Chibi Extension, they don't
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.1.0
    def set_chibi_slave_address(num, address)
      send_request(FUNCTION_SET_CHIBI_SLAVE_ADDRESS, [num, address], 'C C', 0, '')
    end

    # Returns the slave address for a given num as set by 
    # BrickMaster#set_chibi_slave_address.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_slave_address(num)
      send_request(FUNCTION_GET_CHIBI_SLAVE_ADDRESS, [num], 'C', 1, 'C')
    end

    # Returns the signal strength in dBm. The signal strength updates every time a
    # packet is received.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_signal_strength
      send_request(FUNCTION_GET_CHIBI_SIGNAL_STRENGTH, [], '', 1, 'C')
    end

    # Returns underrun, CRC error, no ACK and overflow error counts of the Chibi
    # communication. If these errors start rising, it is likely that either the
    # distance between two Chibi stacks is becoming too big or there are
    # interferences.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_error_log
      send_request(FUNCTION_GET_CHIBI_ERROR_LOG, [], '', 8, 'S S S S')
    end

    # Sets the Chibi frequency range for the Chibi Extension. Possible values are:
    # 
    #  "Type", "Description"
    # 
    #  "0",    "OQPSK 868Mhz (Europe)"
    #  "1",    "OQPSK 915Mhz (US)"
    #  "2",    "OQPSK 780Mhz (China)"
    #  "3",    "BPSK40 915Mhz"
    # 
    # It is possible to set the frequency with the Brick Viewer and it will be 
    # saved in the EEPROM of the Chibi Extension, it does not
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.1.0
    def set_chibi_frequency(frequency)
      send_request(FUNCTION_SET_CHIBI_FREQUENCY, [frequency], 'C', 0, '')
    end

    # Returns the frequency value as set by BrickMaster#set_chibi_frequency.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_frequency
      send_request(FUNCTION_GET_CHIBI_FREQUENCY, [], '', 1, 'C')
    end

    # Sets the channel used by the Chibi Extension. Possible channels are
    # different for different frequencies:
    # 
    #  "Frequency",             "Possible Channels"
    # 
    #  "OQPSK 868Mhz (Europe)", "0"
    #  "OQPSK 915Mhz (US)",     "1, 2, 3, 4, 5, 6, 7, 8, 9, 10"
    #  "OQPSK 780Mhz (China)",  "0, 1, 2, 3"
    #  "BPSK40 915Mhz",         "1, 2, 3, 4, 5, 6, 7, 8, 9, 10"
    # 
    # It is possible to set the frequency with the Brick Viewer and it will be 
    # saved in the EEPROM of the Chibi Extension, it does not
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.1.0
    def set_chibi_channel(channel)
      send_request(FUNCTION_SET_CHIBI_CHANNEL, [channel], 'C', 0, '')
    end

    # Returns the channel as set by BrickMaster#set_chibi_channel.
    # 
    # .. versionadded:: 1.1.0
    def get_chibi_channel
      send_request(FUNCTION_GET_CHIBI_CHANNEL, [], '', 1, 'C')
    end

    # Returns true if a RS485 Extension is available to be used by the Master.
    # 
    # .. versionadded:: 1.2.0
    def is_rs485_present
      send_request(FUNCTION_IS_RS485_PRESENT, [], '', 1, '?')
    end

    # Sets the address (1-255) belonging to the RS485 Extension.
    # 
    # Set to 0 if the RS485 Extension should be the RS485 Master (i.e.
    # connected to a PC via USB).
    # 
    # It is possible to set the address with the Brick Viewer and it will be 
    # saved in the EEPROM of the RS485 Extension, it does not
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.2.0
    def set_rs485_address(address)
      send_request(FUNCTION_SET_RS485_ADDRESS, [address], 'C', 0, '')
    end

    # Returns the address as set by BrickMaster#set_rs485_address.
    # 
    # .. versionadded:: 1.2.0
    def get_rs485_address
      send_request(FUNCTION_GET_RS485_ADDRESS, [], '', 1, 'C')
    end

    # Sets up to 255 slave addresses. The address numeration has to be used
    # ascending from 0. For example: If you use the RS485 Extension in Master mode
    # (i.e. the stack has an USB connection) and you want to talk to three other
    # RS485 stacks with the IDs 17, 23, and 42, you should call with "(0, 17),
    # (1, 23) and (2, 42)".
    # 
    # It is possible to set the addresses with the Brick Viewer and it will be 
    # saved in the EEPROM of the RS485 Extension, they don't
    # have to be set on every startup.
    # 
    # .. versionadded:: 1.2.0
    def set_rs485_slave_address(num, address)
      send_request(FUNCTION_SET_RS485_SLAVE_ADDRESS, [num, address], 'C C', 0, '')
    end

    # Returns the slave address for a given num as set by 
    # BrickMaster#set_rs485_slave_address.
    # 
    # .. versionadded:: 1.2.0
    def get_rs485_slave_address(num)
      send_request(FUNCTION_GET_RS485_SLAVE_ADDRESS, [num], 'C', 1, 'C')
    end

    # Returns CRC error counts of the RS485 communication.
    # If this counter starts rising, it is likely that the distance
    # between the RS485 nodes is too big or there is some kind of
    # interference.
    # 
    # .. versionadded:: 1.2.0
    def get_rs485_error_log
      send_request(FUNCTION_GET_RS485_ERROR_LOG, [], '', 2, 'S')
    end

    # Sets the configuration of the RS485 extension. Speed is given in baud. The
    # Master Brick will try to match the given baud rate as exactly as possible.
    # The maximum recommended baud rate is 2000000 (2Mbit).
    # Possible values for parity are 'n' (none), 'e' (even) and 'o' (odd).
    # Possible values for stopbits are 1 and 2.
    # 
    # If your RS485 is unstable (lost messages etc), the first thing you should
    # try is to decrease the speed. On very large bus (e.g. 1km), you probably
    # should use a value in the range of 100khz.
    # 
    # The values are stored in the EEPROM and only applied on startup. That means
    # you have to restart the Master Brick after configuration.
    # 
    # .. versionadded:: 1.2.0
    def set_rs485_configuration(speed, parity, stopbits)
      send_request(FUNCTION_SET_RS485_CONFIGURATION, [speed, parity, stopbits], 'L k C', 0, '')
    end

    # Returns the configuration as set by BrickMaster#set_rs485_configuration.
    # 
    # .. versionadded:: 1.2.0
    def get_rs485_configuration
      send_request(FUNCTION_GET_RS485_CONFIGURATION, [], '', 6, 'L k C')
    end

    # Calling this function will reset the Brick. Calling this function 
    # on a Brick inside of a stack will reset the whole stack.
    # 
    # After a reset you have to create new device objects, 
    # calling functions on the existing ones will result in 
    # undefined behavior!
    def reset
      send_request(FUNCTION_RESET, [], '', 0, '')
    end

    # Returns the temperature in °C/10 as measured inside the microcontroller. The
    # value returned is not the ambient temperature! 
    # 
    # The temperature has an accuracy of +-15%. Practically it is only usefull as
    # an indicator for temperature changes.
    def get_chip_temperature
      send_request(FUNCTION_GET_CHIP_TEMPERATURE, [], '', 2, 's')
    end

  end
end
